All Classes and Interfaces

Class
Description
Base DevAppServerTestConfig implementation with common defaults: Use /WEB-INF/web.xml.
Used to configure a JUnit4 test that has been annotated with &#64RunWith(DevAppServerTestRunner.class.
Config for a dev appserver that launches as part of a test.
A JUnit4 test runner that runs tests in the isolated classloader of a running app engine app.