Class BaseDevAppServerTestConfig
java.lang.Object
com.google.appengine.tools.development.testing.BaseDevAppServerTestConfig
- All Implemented Interfaces:
DevAppServerTestConfig
Base /WEB-INF/web.xml.
Use /WEB-INF/appengine-web.xml.
Install the security manager.
Make the dev appserver port available in a system property named
DevAppServerTestConfig implementation with common defaults:
Use DEFAULT_PORT_SYSTEM_PROPERTY.-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface com.google.appengine.tools.development.testing.DevAppServerTestConfig
getAppDir, getClasspath, getSdkRoot
-
Field Details
-
DEFAULT_PORT_SYSTEM_PROPERTY
- See Also:
-
-
Constructor Details
-
BaseDevAppServerTestConfig
public BaseDevAppServerTestConfig()
-
-
Method Details
-
getWebXml
- Specified by:
getWebXmlin interfaceDevAppServerTestConfig- Returns:
- The location of web.xml. If
null,DevAppServerTestConfig.getAppDir()/WEB-INF/web.xml will be used.
-
getAppEngineWebXml
- Specified by:
getAppEngineWebXmlin interfaceDevAppServerTestConfig- Returns:
- The location of appengine-web.xml. If
null,DevAppServerTestConfig.getAppDir()/WEB-INF/appengine-web.xml will be used.
-
installSecurityManager
public boolean installSecurityManager()- Specified by:
installSecurityManagerin interfaceDevAppServerTestConfig- Returns:
- If
true, the dev appserver will be installed with the local app engineSecurityManager. It is strongly recommended you install the SecurityManager unless your testing environment does not allow SecurityManager to be installed.
-
getPortSystemProperty
- Specified by:
getPortSystemPropertyin interfaceDevAppServerTestConfig- Returns:
- The name of the system property that can be consulted to retrieve the port on which the dev appserver is running.
-