Annotation Interface DevAppServerTest


@Retention(RUNTIME) @Target(TYPE) @Inherited public @interface DevAppServerTest
Used to configure a JUnit4 test that has been annotated with &#64RunWith(DevAppServerTestRunner.class.
  • Element Details

    • value

      Class<? extends DevAppServerTestConfig> value
      Returns:
      A class that can provide the configuration of the dev appserver that will be launched for the test. This class must be public and have a public, no-arg constructor.