Interface DevAppServerTestConfig

All Known Implementing Classes:
BaseDevAppServerTestConfig

public interface DevAppServerTestConfig
Config for a dev appserver that launches as part of a test.
  • Method Details

    • getSdkRoot

      File getSdkRoot()
      Returns:
      The root of the sdk installation
    • getAppDir

      File getAppDir()
      Returns:
      The top-level directory of the web application to run.
    • getWebXml

      File getWebXml()
      Returns:
      The location of web.xml. If null, getAppDir()/WEB-INF/web.xml will be used.
    • getAppEngineWebXml

      File getAppEngineWebXml()
      Returns:
      The location of appengine-web.xml. If null, getAppDir()/WEB-INF/appengine-web.xml will be used.
    • installSecurityManager

      boolean installSecurityManager()
      Returns:
      If true, the dev appserver will be installed with the local app engine SecurityManager. It is strongly recommended you install the SecurityManager unless your testing environment does not allow SecurityManager to be installed.
    • getClasspath

      List<URL> getClasspath()
      Returns:
      The classpath for all application and test code
    • getPortSystemProperty

      String getPortSystemProperty()
      Returns:
      The name of the system property that can be consulted to retrieve the port on which the dev appserver is running.