Package com.google.appengine.tools.development.testing
package com.google.appengine.tools.development.testing
-
ClassDescriptionBase
DevAppServerTestConfigimplementation with common defaults: Use/WEB-INF/web.xml. Used to configure a JUnit4 test that has been annotated with@RunWith(DevAppServerTestRunner.class.Config for a dev appserver that launches as part of a test.A JUnit4 test runner that runs tests in the isolated classloader of a running app engine app.